@@ -38,16 +38,13 @@ def align_main(ref, r1, r2, sam_path, shfile, rc=False, header=""):
     r1_sam_file = os.path.join(sam_path, os.path.basename(r1).replace(".fastq.gz", ".sam"))
     r2_sam_file = os.path.join(sam_path, os.path.basename(r2).replace(".fastq.gz", ".sam"))
 
-    if not rc: # do not need to check for reverse complement
+    if not rc:
+
         r1_cmd = f"bowtie2 --no-head --norc --no-sq --rdg 12,1 --rfg 12,1 --local -x {ref} -U {r1} -S {r1_sam_file}"
         r2_cmd = f"bowtie2 --no-head --nofw --no-sq --rdg 12,1 --rfg 12,1 --local -x {ref} -U {r2} -S {r2_sam_file}"
     else:
-        # command changed here to match Ian's flags
-        r1_cmd = f"bowtie2 --no-head --no-sq --rdg 6,4 --rfg 6,4 -x {ref} -U {r1} -S {r1_sam_file}"
-        r2_cmd = f"bowtie2 --no-head --no-sq --rdg 6,4 --rfg 6,4 -x {ref} -U {r2} -S {r2_sam_file}"
-
-        # r1_cmd = f"bowtie2 --no-head --no-sq --rdg 12,1 --rfg 12,1 --local -x {ref} -U {r1} -S {r1_sam_file}"
-        # r2_cmd = f"bowtie2 --no-head --no-sq --rdg 12,1 --rfg 12,1 --local -x {ref} -U {r2} -S {r2_sam_file}"
+        r1_cmd = f"bowtie2 --no-head --no-sq --rdg 12,1 --rfg 12,1 --local -x {ref} -U {r1} -S {r1_sam_file}"
+        r2_cmd = f"bowtie2 --no-head --no-sq --rdg 12,1 --rfg 12,1 --local -x {ref} -U {r2} -S {r2_sam_file}"
 
     with open(shfile, "w") as f:
         # header is only used on galen
