@@ -68,10 +68,15 @@ class readSam(object):
         # init a new object for logging, log to sample specific file.log
         # log_f = os.path.join(output_dir, f"sample_{str(self._sample_id)}_mut_count.log")
         # log_object = help_functions.logginginit(arguments.log_level, log_f)
-
+        # path for the output files
         self._sample_counts_f = os.path.join(self._output_counts_dir,f"counts_sample_{self._sample_id}.csv")
         self._sample_counts_r1_f = os.path.join(self._output_counts_dir, f"counts_sample_{self._sample_id}_r1.csv")
         self._sample_counts_r2_f = os.path.join(self._output_counts_dir, f"counts_sample_{self._sample_id}_r2.csv")
+        # file used to track reads mapped outside of the tile
+        self._sample_offreads_f = os.path.join(self._output_counts_dir,f"offreads_{self._sample_id}.csv")
+        offreads = open(self._sample_offreads_f, "w")
+        offreads.write("r1_start, r1_len, r2_start, r2_len\n")
+        offreads.close()
 
         self._base = arguments.base
         self._posteriorQC = arguments.posteriorQC
@@ -116,6 +121,9 @@ class readSam(object):
         self._track_reads = self._track_reads.set_index("pos")
         self._track_reads = self._track_reads.fillna(0)
 
+        # single replicate override
+        self._sroverride = arguments.sr_Override
+
     def adjust_er(self, wt_override=False):
         """
         Based on the wt samples given in the parameter sheet,
@@ -178,6 +186,8 @@ class readSam(object):
                 pass
             log_f = os.path.join(self._output_counts_dir, f"{wt_id}_R1_phred.log")
             cmd_r1 = f"calibratePhred.R {self._r1} -p {self._param} -o {phred_output_r1} -l {log_f} --silent --cores {self._cores}"
+            if self._sroverride:
+                cmd_r1 = cmd_r1 + " --srOverride"
             self._mut_log.info(cmd_r1)
             os.system(cmd_r1)
         if not os.path.isfile(phred_output_r2):
@@ -186,6 +196,8 @@ class readSam(object):
                 pass
             log_f = os.path.join(self._output_counts_dir, f"{wt_id}_R2_phred.log")
             cmd_r2 = f"calibratePhred.R {self._r2} -p {self._param} -o {phred_output_r2} -l {log_f} --silent --cores {self._cores}"
+            if self._sroverride:
+                cmd_r2 = cmd_r2 + " --srOverride"
             self._mut_log.info(cmd_r2)
             os.system(cmd_r2)
         
@@ -213,7 +225,6 @@ class readSam(object):
         self._mut_log.info(f"Adjusted thred files generated: {phred_output_r1}, {phred_output_r2}")
         return [phred_output_r1, phred_output_r2]
 
-
     def adjust_er_phix(self):
         """
         If not phix thred adjusted, run calibratePhred.R with phix reads
@@ -242,6 +253,8 @@ class readSam(object):
 
             log_f = os.path.join(self._output_counts_dir, f"phix_phred.log")
             cmd = f"calibratePhred.R {phix_r1} -p {self._param} -o {phred_output_r1} -l {log_f} --silent --cores {self._cores} --fastaref {phix_fasta}"
+            if self._sroverride:
+                cmd = cmd + " --srOverride"
             os.system(cmd)
         if not os.path.isfile(phred_output_r2):
             # create an empty file as place holder
@@ -255,6 +268,8 @@ class readSam(object):
             log_f = os.path.join(self._output_counts_dir, f"phix_phred.log")
             cmd = f"calibratePhred.R {phix_r2} -p {self._param} -o {phred_output_r2} -l {log_f} --silent --cores" \
                   f" {self._cores} --fastaref {phix_fasta}"
+            if self._sroverride:
+                cmd = cmd + " --srOverride"
             os.system(cmd)
 
         # check if both file has something in there
@@ -299,6 +314,14 @@ class readSam(object):
         r2_popmut = 0
         off_read = 0
 
+        # used to track read len for read 1 and read 2
+        # this information will be written in the counts file
+        read_length_r1 = {}
+        read_length_r2 = {}
+
+        # used to track reads mapped outside of a tile
+        offmap = open(self._sample_offreads_f, "a")
+
         r1_f = open(self._r1, "r")
         r2_f = open(self._r2, "r")
         # init objects
@@ -335,17 +358,11 @@ class readSam(object):
             # get starting position for r1 and r2
             pos_start_r1 = line_r1[3]
             pos_start_r2 = line_r2[3]
+
             # record reads that are not mapped to this tile
             # this is defined as if the read covers at least min_map percent of the tile
             # the default min_map is 70%
             # we also assume that the read len is ALWAYS 150
-            r1_end = int(pos_start_r1) + 150
-            # r1_end must cover from start of the tile to 70% of the tile
-            if ((r1_end - int(self._cds_start)) < (int(self._tile_begins) + int(self._min_map_len))) or \
-                    ((int(pos_start_r2) - int(self._cds_start)) > (int(self._tile_ends) - int(self._min_map_len))):
-                off_read += 1
-                continue
-
             # get CIGAR string
             CIGAR_r1 = line_r1[5]
             seq_r1 = line_r1[9]
@@ -355,6 +372,18 @@ class readSam(object):
             seq_r2 = line_r2[9]
             quality_r2 = line_r2[10]
 
+            r1_end = int(pos_start_r1) + len(seq_r1)
+            r2_end = int(pos_start_r2) + len(seq_r2)
+            # read 1 sequence must cover from start of the tile to 70% of the tile
+            if ((r1_end - int(self._cds_start)) < (int(self._tile_begins) + int(self._min_map_len))) or \
+                    ((r2_end - int(self._cds_start)) < (int(self._tile_begins) + int(self._min_map_len))):
+                #todo keep track of read start and end position for read 1 and read 2
+                offmap.write(f"{int(pos_start_r1) - int(self._cds_start)}, {len(seq_r1)}, {int(pos_start_r2) - int(self._cds_start)}, {len(seq_r2)}\n")
+                off_read += 1
+                #print(seq_r1, pos_start_r1, r1_end)
+                #print(seq_r2, pos_start_r2)
+                continue
+
             mdz_r1 = [i for i in line_r1 if "MD:Z:" in i]
             mdz_r2 = [i for i in line_r2 if "MD:Z:" in i]
 
@@ -392,13 +421,29 @@ class readSam(object):
             row["cigar_r2"] = CIGAR_r2
             row["mdz_r2"] = mdz_r2
             row["seq_r2"] = seq_r2
+
+            # for all the reads that reached to this stage, check the read len for R1 and R2
+            # read len = length of the actual reads
+            read_len_r1 = len(seq_r1)
+            read_len_r2 = len(seq_r2)
+
+            if read_length_r1.get(read_len_r1, -1) == -1:
+                read_length_r1[read_len_r1] = 1
+            else:
+                read_length_r1[read_len_r1] += 1
+
+            if read_length_r2.get(read_len_r2, -1) == -1:
+                read_length_r2[read_len_r2] = 1
+            else:
+                read_length_r2[read_len_r2] += 1
+
             # mut_parser = locate_mut.MutParser(row, self._seq, self._cds_seq, self._seq_lookup, self._tile_begins,
                                               # self._tile_ends, self._qual, self._locate_log, self._mutrate)
             jobs.append(pool.apply_async(process_wrapper, (row, self._seq, self._cds_seq, self._seq_lookup, self._tile_begins,
                                                self._tile_ends, self._qual, self._mut_log, self._mutrate,
                                                            self._base, self._posteriorQC, adjusted_er)))
             row = {} # flush
-
+        offmap.close()
         r1_f.close()
         r2_f.close()
         self._mut_log.info("File streamed to subprocesses, waiting for jobs to finish")
@@ -464,7 +509,8 @@ class readSam(object):
         output_csv.write(f"#Total read pairs with mutations:{final_pairs}\n")
         output_csv.write(
             f"#Comment: Total read pairs with mutations = Read pairs with mutations that passed the posterior threshold\n#Comment: Final read-depth = raw read depth - reads didn't map to gene - reads mapped outside of the tile\n")
-
+        output_csv.write(f"#Read len for R1: {read_length_r1}\n")
+        output_csv.write(f"#Read len for R2: {read_length_r2}\n")
         output_csv.close()
 
         self._mut_log.info(f"Raw sequencing depth: {read_pair}")
@@ -510,7 +556,6 @@ class readSam(object):
 def process_wrapper(row, seq, cds_seq, seq_lookup, tile_begins, tile_ends, qual, locate_log, mutrate, base,
                     posteriorQC, adjusted_er):
     """
-
     """
     mut_parser = locate_mut.MutParser(row, seq, cds_seq, seq_lookup, tile_begins, tile_ends, qual, locate_log,
                                       mutrate, base, posteriorQC, adjusted_er)
